@@ -7,6 +7,7 @@
  */
 
 #include "Listener.h"
+#include "znc.h"
 
 CListener::~CListener() {
 	if (m_pListener)
@@ -15,6 +16,7 @@ CListener::~CListener() {
 
 bool CListener::Listen() {
 	if (!m_uPort || m_pListener) {
+		errno = EINVAL;
 		return false;
 	}
 
@@ -28,6 +30,10 @@ bool CListener::Listen() {
 	}
 #endif
 
+	// If e.g. getaddrinfo() fails, the following might not set errno.
+	// Make sure there is a consistent error message, not something random
+	// which might even be "Error: Success".
+	errno = EINVAL;
 	return CZNC::Get().GetManager().ListenHost(m_uPort, "_LISTENER", m_sBindHost, bSSL, SOMAXCONN,
 			m_pListener, 0, m_eAddr);
 }
@@ -63,6 +69,9 @@ void CRealListener::SockError(int iErrno) {
 	if (iErrno == EMFILE) {
 		// We have too many open fds, let's close this listening port to be able to continue
 		// to work, next rehash will (try to) reopen it.
+		CZNC::Get().Broadcast("We hit the FD limit, closing listening socket on ["
+				+ GetLocalIP() + " : " + CString(GetLocalPort()) + "]");
+		CZNC::Get().Broadcast("An admin has to rehash to reopen the listening port");
 		Close();
 	}
 }
