@@ -18,21 +18,83 @@
 using std::stringstream;
 
 class CNotesMod : public CModule {
+	bool bShowNotesOnLogin;
+
+	void ListCommand(const CString &sLine) {
+		ListNotes();
+	}
+
+	void AddNoteCommand(const CString &sLine) {
+		CString sKey(sLine.Token(1));
+		CString sValue(sLine.Token(2, true));
+
+		if (!GetNV(sKey).empty()) {
+			PutModule("That note already exists.  Use MOD <key> <note> to overwrite.");
+		} else if (AddNote(sKey, sValue)) {
+			PutModule("Added note [" + sKey + "]");
+		} else {
+			PutModule("Unable to add note [" + sKey + "]");
+		}
+	}
+
+	void ModCommand(const CString &sLine) {
+		CString sKey(sLine.Token(1));
+		CString sValue(sLine.Token(2, true));
+
+		if (AddNote(sKey, sValue)) {
+			PutModule("Set note for [" + sKey + "]");
+		} else {
+			PutModule("Unable to add note [" + sKey + "]");
+		}
+	}
+
+	void GetCommand(const CString &sLine) {
+		CString sNote = GetNV(sLine.Token(1, true));
+
+		if (sNote.empty()) {
+			PutModule("This note doesn't exist.");
+		} else {
+			PutModule(sNote);
+		}
+	}
+
+	void DelCommand(const CString &sLine) {
+		CString sKey(sLine.Token(1));
+
+		if (DelNote(sKey)) {
+			PutModule("Deleted note [" + sKey + "]");
+		} else {
+			PutModule("Unable to delete note [" + sKey + "]");
+		}
+	}
+
 public:
 	MODCONSTRUCTOR(CNotesMod) {
+		AddHelpCommand();
+		AddCommand("List",   static_cast<CModCommand::ModCmdFunc>(&CNotesMod::ListCommand));
+		AddCommand("Add",    static_cast<CModCommand::ModCmdFunc>(&CNotesMod::AddNoteCommand),
+			"<key> <note>");
+		AddCommand("Del",    static_cast<CModCommand::ModCmdFunc>(&CNotesMod::DelCommand),
+			"<key>",         "Delete a note");
+		AddCommand("Mod",    static_cast<CModCommand::ModCmdFunc>(&CNotesMod::ModCommand),
+			"<key> <note>",  "Modify a note");
+		AddCommand("Get",    static_cast<CModCommand::ModCmdFunc>(&CNotesMod::GetCommand),
+			"<key>");
 	}
 
-	virtual ~CNotesMod() {
-	}
+	virtual ~CNotesMod() {}
 
-	virtual bool OnLoad(const CString& sArgStr, CString& sMessage) {
+	virtual bool OnLoad(const CString& sArgs, CString& sMessage) {
+		bShowNotesOnLogin = !sArgs.Equals("-disableNotesOnLogin");
 		return true;
 	}
 
 	virtual CString GetWebMenuTitle() { return "Notes"; }
 
 	virtual void OnClientLogin() {
-		ListNotes(true);
+		if (bShowNotesOnLogin) {
+			ListNotes(true);
+		}
 	}
 
 	virtual EModRet OnUserRaw(CString& sLine) {
@@ -126,44 +188,6 @@ public:
 		}
 	}
 
-	virtual void OnModCommand(const CString& sLine) {
-		CString sCmd(sLine.Token(0));
-
-		if (sLine.Equals("LIST")) {
-			ListNotes();
-		} else if (sCmd.Equals("ADD")) {
-			CString sKey(sLine.Token(1));
-			CString sValue(sLine.Token(2, true));
-
-			if (!GetNV(sKey).empty()) {
-				PutModule("That note already exists.  Use MOD <key> <note> to overwrite.");
-			} else if (AddNote(sKey, sValue)) {
-				PutModule("Added note [" + sKey + "]");
-			} else {
-				PutModule("Unable to add note [" + sKey + "]");
-			}
-		} else if (sCmd.Equals("MOD")) {
-			CString sKey(sLine.Token(1));
-			CString sValue(sLine.Token(2, true));
-
-			if (AddNote(sKey, sValue)) {
-				PutModule("Set note for [" + sKey + "]");
-			} else {
-				PutModule("Unable to add note [" + sKey + "]");
-			}
-		} else if (sCmd.Equals("DEL")) {
-			CString sKey(sLine.Token(1));
-
-			if (DelNote(sKey)) {
-				PutModule("Deleted note [" + sKey + "]");
-			} else {
-				PutModule("Unable to delete note [" + sKey + "]");
-			}
-		} else {
-			PutModule("Commands are: Help, List, Add <key> <note>, Del <key>, Mod <key> <note>");
-		}
-	}
-
 	virtual bool OnWebRequest(CWebSock& WebSock, const CString& sPageName, CTemplate& Tmpl) {
 		if (sPageName == "index") {
 			for (MCString::iterator it = BeginNV(); it != EndNV(); ++it) {
@@ -188,4 +212,8 @@ public:
 	}
 };
 
+template<> void TModInfo<CNotesMod>(CModInfo& Info) {
+	Info.SetWikiPage("notes");
+}
+
 MODULEDEFS(CNotesMod, "Keep and replay notes")
