@@ -308,7 +308,8 @@ public:
 
 		if (GetNV("silent_timeouts") != "yes") {
 			PutModule("This module hit a timeout which is possibly a bug.");
-			PutModule("Use \"silent yes\" to disable this message.");
+			PutModule("To disable this message, do \"/msg " + GetModNick()
+					+ " silent yes\"");
 			PutModule("Last request: " + m_sLastRequest);
 			PutModule("Expected replies: ");
 
@@ -422,4 +423,8 @@ void CRouteTimeout::RunJob()
 	pMod->Timeout();
 }
 
+template<> void TModInfo<CRouteRepliesMod>(CModInfo& Info) {
+	Info.SetWikiPage("route_replies");
+}
+
 MODULEDEFS(CRouteRepliesMod, "Send replies (e.g. to /who) to the right client only")
