@@ -84,10 +84,7 @@ public:
 			return false;
 		if (!Nick.GetHostMask().AsLower().WildCmp(m_sHostMask.AsLower()))
 			return false;
-		if (!sText.AsLower().WildCmp(pUser->ExpandString(m_sPattern).AsLower()))
-			return false;
-
-		return true;
+		return (sText.AsLower().WildCmp(pUser->ExpandString(m_sPattern).AsLower()));
 	}
 
 	bool operator ==(const CWatchEntry& WatchEntry) {
@@ -178,7 +175,7 @@ public:
 	}
 
 	virtual void OnKick(const CNick& OpNick, const CString& sKickedNick, CChan& Channel, const CString& sMessage) {
-		Process(OpNick, "* " + OpNick.GetNick() + " kicked " + sKickedNick + " from " + 
+		Process(OpNick, "* " + OpNick.GetNick() + " kicked " + sKickedNick + " from " +
 			Channel.GetName() + " because [" + sMessage + "]", Channel.GetName());
 	}
 
@@ -553,4 +550,8 @@ private:
 	CBuffer            m_Buffer;
 };
 
+template<> void TModInfo<CWatcherMod>(CModInfo& Info) {
+	Info.SetWikiPage("watch");
+}
+
 MODULEDEFS(CWatcherMod, "Copy activity from a specific user into a separate window")
